# natural_units

Wrapper for various units:

| Unit      | Description |
| ----------- | ----------- |
| base      | general super class       |
| si        | m,kg,s,A,K,mol,cd basis        |
| natural   | $c=\hbar=1$, checks mass dimension compatibility        |
| num       | $c=\hbar=1$, like natural, but without mass dimension checks        |
